pub enum Editor {
Hx,
Nvim,
}Expand description
Supported text editors for file operations.
Variants
Implementations
Sourceimpl Editor
impl Editor
Sourcepub fn open_file_cmd(&self, file_to_open: &FileToOpen) -> String
pub fn open_file_cmd(&self, file_to_open: &FileToOpen) -> String
Generates a command string to open the specified FileToOpen in the Editor.
Sourcepub const fn pane_titles(&self) -> &[&str]
pub const fn pane_titles(&self) -> &[&str]
Returns the pane titles associated with the Editor variant.